==> galileo-1.26.0.tar.gz: galileo-1.26.0/src/galileo/resources/api/prompts/create_group_prompt_template_collaborators_templates_template_id_groups_post.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.group_collaborator import GroupCollaborator
from ...models.group_collaborator_create import GroupCollaboratorCreate
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(template_id: str, *, body: list["GroupCollaboratorCreate"]) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.POST,
        "return_raw_response": True,
        "path": f"/templates/{template_id}/groups",
    }

    _kwargs["json"] = []
    for body_item_data in body:
        body_item = body_item_data.to_dict()
        _kwargs["json"].append(body_item)

    headers["Content-Type"] = "application/json"

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = GroupCollaborator.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Response[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, list['GroupCollaborator']]]
    """

    kwargs = _get_kwargs(template_id=template_id, body=body)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Optional[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, list['GroupCollaborator']]
    """

    return sync_detailed(template_id=template_id, client=client, body=body).parsed


async def asyncio_detailed(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Response[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, list['GroupCollaborator']]]
    """

    kwargs = _get_kwargs(template_id=template_id, body=body)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Optional[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, list['GroupCollaborator']]
    """

    return (await asyncio_detailed(template_id=template_id, client=client, body=body)).parsed

==> galileo-1.28.0.tar.gz: galileo-1.28.0/src/galileo/resources/api/prompts/create_group_prompt_template_collaborators_templates_template_id_groups_post.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.group_collaborator import GroupCollaborator
from ...models.group_collaborator_create import GroupCollaboratorCreate
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(template_id: str, *, body: list["GroupCollaboratorCreate"]) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.POST,
        "return_raw_response": True,
        "path": f"/templates/{template_id}/groups",
    }

    _kwargs["json"] = []
    for body_item_data in body:
        body_item = body_item_data.to_dict()
        _kwargs["json"].append(body_item)

    headers["Content-Type"] = "application/json"

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = GroupCollaborator.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Response[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators.

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[HTTPValidationError, list['GroupCollaborator']]]
    """
    kwargs = _get_kwargs(template_id=template_id, body=body)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Optional[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators.

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[HTTPValidationError, list['GroupCollaborator']]
    """
    return sync_detailed(template_id=template_id, client=client, body=body).parsed


async def asyncio_detailed(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Response[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators.

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[HTTPValidationError, list['GroupCollaborator']]]
    """
    kwargs = _get_kwargs(template_id=template_id, body=body)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    template_id: str, *, client: ApiClient, body: list["GroupCollaboratorCreate"]
) -> Optional[Union[HTTPValidationError, list["GroupCollaborator"]]]:
    """Create Group Prompt Template Collaborators.

     Share a prompt template with groups.

    Args:
        template_id (str):
        body (list['GroupCollaboratorCreate']):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[HTTPValidationError, list['GroupCollaborator']]
    """
    return (await asyncio_detailed(template_id=template_id, client=client, body=body)).parsed
